@@ -172,21 +172,18 @@ DownloadFactory::receive_success() {
   // Move to 'rtorrent'.
   download->variable()->set("connection_leech", m_variables.get("connection_leech"));
   download->variable()->set("connection_seed",  m_variables.get("connection_seed"));
+
+  download->variable()->set("max_uploads",      control->variable()->get("max_uploads"));
   download->variable()->set("min_peers",        control->variable()->get("min_peers"));
   download->variable()->set("max_peers",        control->variable()->get("max_peers"));
-  download->variable()->set("max_uploads",      control->variable()->get("max_uploads"));
 
-  if (!control->variable()->get_value("timeout_sync") != 0)
-    download->variable()->set("timeout_sync", control->variable()->get("timeout_sync"));
+  if (download->variable()->get_value("complete") != 0) {
+    if (control->variable()->get_value("min_peers_seed") >= 0)
+      download->variable()->set("min_peers", control->variable()->get("min_peers_seed"));
 
-  if (!control->variable()->get_value("timeout_safe_sync") != 0)
-    download->variable()->set("timeout_safe_sync", control->variable()->get("timeout_safe_sync"));
-
-  if (!control->variable()->get_value("max_chunks_queued") != 0)
-    download->variable()->set("max_chunks_queued", control->variable()->get("max_chunks_queued"));
-  else
-    // Temporary until we fix the library.
-    download->variable()->set("max_chunks_queued", (512 << 20) / download->download()->chunks_size());
+    if (control->variable()->get_value("max_peers_seed") >= 0)
+      download->variable()->set("max_peers", control->variable()->get("max_peers_seed"));
+  }
 
   if (!control->variable()->get_value("use_udp_trackers"))
     download->enable_udp_trackers(false);
@@ -205,6 +202,7 @@ DownloadFactory::receive_success() {
 
   torrent::resume_load_addresses(*download->download(), resumeObject);
   torrent::resume_load_file_priorities(*download->download(), resumeObject);
+  torrent::resume_load_tracker_settings(*download->download(), resumeObject);
 
   // The action of inserting might cause the torrent to be
   // opened/started or such. Figure out a nicer way of handling this.
