@@ -36,8 +36,9 @@
 
 #include "config.h"
 
-#include <stdexcept>
+#include <torrent/exceptions.h>
 
+#include "display/frame.h"
 #include "input/manager.h"
 
 #include "control.h"
@@ -50,23 +51,28 @@ ElementStringList::ElementStringList() :
 }
 
 void
-ElementStringList::activate(Control* c, MItr mItr) {
-  if (m_window != NULL)
-    throw std::logic_error("ui::ElementStringList::activate(...) called on an object in the wrong state");
+ElementStringList::activate(display::Frame* frame, bool focus) {
+  if (is_active())
+    throw torrent::client_error("ui::ElementStringList::activate(...) is_active().");
 
-  c->input()->push_front(&m_bindings);
+  control->input()->push_back(&m_bindings);
 
-  *mItr = m_window = new WStringList();
+  m_window = new WStringList();
+  m_window->set_active(true);
 
-  m_window->set_range(m_list.begin(), m_list.end());
+  m_frame = frame;
+  m_frame->initialize_window(m_window);
 }
 
 void
-ElementStringList::disable(Control* c) {
-  if (m_window == NULL)
-    throw std::logic_error("ui::ElementStringList::disable(...) called on an object in the wrong state");
+ElementStringList::disable() {
+  if (!is_active())
+    throw torrent::client_error("ui::ElementStringList::disable(...) !is_active().");
 
-  c->input()->erase(&m_bindings);
+  control->input()->erase(&m_bindings);
+
+  m_frame->clear();
+  m_frame = NULL;
 
   delete m_window;
   m_window = NULL;
